@@ -26,6 +26,25 @@ private Q_SLOTS:
     {
     }
 
+    void test_classify_data()
+    {
+        QTest::addColumn<QString>("fileName");
+        QTest::addColumn<unsigned int>("result");
+
+        QTest::newRow("*.sig") << u"XXXXXX.sig"_s << unsigned(Kleo::Class::OpenPGP | Kleo::Class::AnyFormat | Kleo::Class::DetachedSignature);
+        QTest::newRow("*.SIG") << u"XXXXXX.SIG"_s << unsigned(Kleo::Class::OpenPGP | Kleo::Class::AnyFormat | Kleo::Class::DetachedSignature);
+    }
+
+    void test_classify()
+    {
+        QFETCH(QString, fileName);
+        QFETCH(unsigned int, result);
+
+        QTemporaryFile tempfile{fileName};
+        QVERIFY(tempfile.open());
+        QCOMPARE(Kleo::classify(tempfile.fileName()), result);
+    }
+
     void identifyFileName()
     {
         QTemporaryDir dir;
@@ -44,43 +63,47 @@ private Q_SLOTS:
         QVERIFY(Kleo::isMimeFile(fileName1));
     }
 
-    void identifyMimeFileExtensionTest()
+    void test_mayBeMimeFile_fileName_data()
     {
-        {
-            QTemporaryFile mbox;
-            mbox.setFileTemplate("XXXXXX.mbox");
-            QVERIFY(mbox.open());
-            QVERIFY(Kleo::mayBeMimeFile(Kleo::classify(mbox.fileName())));
-        }
+        QTest::addColumn<QString>("fileName");
+        QTest::addColumn<bool>("result");
 
-        {
-            QTemporaryFile eml;
-            eml.setFileTemplate("XXXXXX.eml");
-            QVERIFY(eml.open());
-            QVERIFY(Kleo::mayBeMimeFile(eml.fileName()));
+        QTest::newRow("*.mbox") << u"XXXXXX.mbox"_s << true;
+        QTest::newRow("*.eml") << u"XXXXXX.eml"_s << true;
+        QTest::newRow("*.p7m") << u"XXXXXX.p7m"_s << true;
+        QTest::newRow("*.P7M") << u"XXXXXX.P7M"_s << true;
+        QTest::newRow("*.pdf.p7m") << u"XXXXXX.pdf.p7m"_s << false;
+    }
 
-            QCOMPARE(QStringLiteral("Ascii, MimeFile"), Kleo::printableClassification(Kleo::classify(eml.fileName())));
-        }
+    void test_mayBeMimeFile_fileName()
+    {
+        QFETCH(QString, fileName);
+        QFETCH(bool, result);
 
-        {
-            QTemporaryFile myFile;
-            myFile.setFileTemplate("XXXXXX.p7m");
-            QVERIFY(myFile.open());
-            QVERIFY(Kleo::mayBeMimeFile(myFile.fileName()));
-        }
+        QTemporaryFile tempfile;
+        tempfile.setFileTemplate(fileName);
+        QVERIFY(tempfile.open());
+        QCOMPARE(Kleo::mayBeMimeFile(tempfile.fileName()), result);
+    }
 
-        {
-            QTemporaryFile myPdfFile;
-            myPdfFile.setFileTemplate("XXXXXX.pdf.p7m");
-            QVERIFY(myPdfFile.open());
-            QVERIFY(!Kleo::mayBeMimeFile(myPdfFile.fileName()));
-        }
+    void test_mayBeMimeFile_classification()
+    {
+        QVERIFY(Kleo::mayBeMimeFile(Kleo::Class::MimeFile | Kleo::Class::Ascii));
+    }
+
+    void test_printableClassification()
+    {
+        QTemporaryFile eml;
+        eml.setFileTemplate(u"XXXXXX.eml"_s);
+        QVERIFY(eml.open());
+
+        QCOMPARE(QStringLiteral("Ascii, MimeFile"), Kleo::printableClassification(Kleo::classify(eml.fileName())));
     }
 
     void identifyCertificateStoreExtensionTest()
     {
         QTemporaryFile crl;
-        crl.setFileTemplate("XXXXXX.crl");
+        crl.setFileTemplate(u"XXXXXX.crl"_s);
         QVERIFY(crl.open());
         QVERIFY(Kleo::isCertificateRevocationList(crl.fileName()));
     }
@@ -88,7 +111,7 @@ private Q_SLOTS:
     void findSignaturesTest()
     {
         QTemporaryFile sig;
-        sig.setFileTemplate("XXXXXX.sig");
+        sig.setFileTemplate(u"XXXXXX.sig"_s);
         QVERIFY(sig.open());
 
         QFileInfo fi(sig.fileName());
@@ -98,22 +121,22 @@ private Q_SLOTS:
         QCOMPARE(fi.baseName() + QStringLiteral(".sig"), signatures[0]);
     }
 
-    void findOutputFileNameNotFoundTest()
+    void test_outputFileName_data()
     {
-        QTemporaryFile unknown;
-        unknown.setFileTemplate("XXXXXX.unknown");
-        QVERIFY(unknown.open());
+        QTest::addColumn<QString>("fileName");
+        QTest::addColumn<QString>("result");
 
-        QCOMPARE(unknown.fileName() + QStringLiteral(".out"), Kleo::outputFileName(unknown.fileName()));
+        QTest::newRow("known extension") << u"XXXXXX.sig"_s << u"XXXXXX"_s;
+        QTest::newRow("unknown extension") << u"XXXXXX.unknown"_s << u"XXXXXX.unknown.out"_s;
+        QTest::newRow("upper-case extension") << u"XXXXXX.GPG"_s << u"XXXXXX"_s;
     }
 
-    void findOutputFileNameTest()
+    void test_outputFileName()
     {
-        QTemporaryFile sig;
-        sig.setFileTemplate("XXXXXX.sig");
-        QVERIFY(sig.open());
+        QFETCH(QString, fileName);
+        QFETCH(QString, result);
 
-        QCOMPARE(sig.fileName().chopped(4), Kleo::outputFileName(sig.fileName()));
+        QCOMPARE(Kleo::outputFileName(fileName), result);
     }
 
     void test_outputFileExtension()
