@@ -17,6 +17,7 @@
 #include <libkleo/keyserverconfig.h>
 
 #include <KCollapsibleGroupBox>
+#include <KColorScheme>
 #include <KConfigGroup>
 #include <KGuiItem>
 #include <KLocalizedString>
@@ -62,8 +63,9 @@ class EditDirectoryServiceDialog::Private
         QLineEdit *baseDnEdit = nullptr;
         QLineEdit *additionalFlagsEdit = nullptr;
         QDialogButtonBox *buttonBox = nullptr;
+        QLabel *invalidHostLabel = nullptr;
 
-        Ui(QWidget *parent)
+        explicit Ui(QWidget *parent)
             : hostEdit{new QLineEdit{parent}}
             , portSpinBox{new QSpinBox{parent}}
             , useDefaultPortCheckBox{new QCheckBox{parent}}
@@ -75,6 +77,7 @@ class EditDirectoryServiceDialog::Private
             , baseDnEdit{new QLineEdit{parent}}
             , additionalFlagsEdit{new QLineEdit{parent}}
             , buttonBox{new QDialogButtonBox{parent}}
+            , invalidHostLabel{new QLabel{parent}}
         {
 #define SET_OBJECT_NAME(x) x->setObjectName(QStringLiteral(#x));
             SET_OBJECT_NAME(hostEdit)
@@ -101,6 +104,15 @@ class EditDirectoryServiceDialog::Private
                 hostEdit->setClearButtonEnabled(true);
                 layout->addWidget(hostEdit, row, 1, 1, -1);
                 ++row;
+                const auto colors = KColorScheme(QPalette::Active, KColorScheme::View);
+                QPalette palette;
+                palette.setBrush(QPalette::Window, colors.background(KColorScheme::NegativeBackground));
+                palette.setBrush(QPalette::WindowText, colors.foreground(KColorScheme::NegativeText));
+                invalidHostLabel->setPalette(palette);
+                invalidHostLabel->setText(i18nc("@info:label", "Error: Enter a hostname in the correct format, like ldap.example.com."));
+                invalidHostLabel->setVisible(false);
+                layout->addWidget(invalidHostLabel, row, 1, 1, 2);
+                ++row;
                 layout->addWidget(new QLabel{i18n("Port:")}, row, 0);
                 portSpinBox->setRange(1, USHRT_MAX);
                 portSpinBox->setToolTip(i18nc("@info:tooltip",
@@ -285,8 +297,11 @@ class EditDirectoryServiceDialog::Private
     bool inputIsAcceptable() const
     {
         const bool hostIsSet = !host().isEmpty();
+        QUrl url;
+        url.setHost(host());
+        ui.invalidHostLabel->setVisible(!url.isValid());
         const bool requiredCredentialsAreSet = authentication() != KeyserverAuthentication::Password || (!user().isEmpty() && !password().isEmpty());
-        return hostIsSet && requiredCredentialsAreSet;
+        return hostIsSet && requiredCredentialsAreSet && url.isValid();
     }
 
     void updateWidgets()
@@ -303,7 +318,7 @@ class EditDirectoryServiceDialog::Private
     }
 
 public:
-    Private(EditDirectoryServiceDialog *q)
+    explicit Private(EditDirectoryServiceDialog *q)
         : q{q}
         , ui{q}
     {
@@ -373,14 +388,14 @@ public:
 private:
     void saveLayout()
     {
-        KConfigGroup configGroup{KSharedConfig::openStateConfig(), QLatin1String("EditDirectoryServiceDialog")};
+        KConfigGroup configGroup{KSharedConfig::openStateConfig(), QLatin1StringView("EditDirectoryServiceDialog")};
         configGroup.writeEntry("Size", q->size());
         configGroup.sync();
     }
 
     void restoreLayout()
     {
-        const KConfigGroup configGroup{KSharedConfig::openStateConfig(), QLatin1String("EditDirectoryServiceDialog")};
+        const KConfigGroup configGroup{KSharedConfig::openStateConfig(), QLatin1StringView("EditDirectoryServiceDialog")};
         const auto size = configGroup.readEntry("Size", QSize{});
         if (size.isValid()) {
             q->resize(size);
